aboutsummaryrefslogtreecommitdiffstats
path: root/package/kernel/mac80211/patches/523-mac80211_configure_antenna_gain.patch
diff options
context:
space:
mode:
Diffstat (limited to 'package/kernel/mac80211/patches/523-mac80211_configure_antenna_gain.patch')
-rw-r--r--package/kernel/mac80211/patches/523-mac80211_configure_antenna_gain.patch20
1 files changed, 10 insertions, 10 deletions
diff --git a/package/kernel/mac80211/patches/523-mac80211_configure_antenna_gain.patch b/package/kernel/mac80211/patches/523-mac80211_configure_antenna_gain.patch
index 12937e6eb1..00265e9e0e 100644
--- a/package/kernel/mac80211/patches/523-mac80211_configure_antenna_gain.patch
+++ b/package/kernel/mac80211/patches/523-mac80211_configure_antenna_gain.patch
@@ -36,9 +36,9 @@
u8 ps_dtim_period;
--- a/net/mac80211/cfg.c
+++ b/net/mac80211/cfg.c
-@@ -2304,6 +2304,19 @@ static int ieee80211_get_tx_power(struct
+@@ -2308,6 +2308,19 @@ static int ieee80211_get_tx_power(struct
return 0;
}
@@ -77,7 +77,7 @@
static int ieee80211_set_wds_peer(struct wiphy *wiphy, struct net_device *dev,
const u8 *addr)
{
-@@ -3839,6 +3852,7 @@ struct cfg80211_ops mac80211_config_ops
+@@ -3861,6 +3874,7 @@ struct cfg80211_ops mac80211_config_ops
.set_wiphy_params = ieee80211_set_wiphy_params,
.set_tx_power = ieee80211_set_tx_power,
.get_tx_power = ieee80211_get_tx_power,
@@ -87,7 +87,7 @@
CFG80211_TESTMODE_CMD(ieee80211_testmode_cmd)
--- a/net/mac80211/ieee80211_i.h
+++ b/net/mac80211/ieee80211_i.h
-@@ -1182,6 +1182,7 @@ struct ieee80211_local {
+@@ -1185,6 +1185,7 @@ struct ieee80211_local {
int dynamic_ps_forced_timeout;
int user_power_level; /* in dBm, for all interfaces */
@@ -147,7 +147,7 @@
};
/* policy for the key attributes */
-@@ -2038,6 +2039,22 @@ static int nl80211_set_wiphy(struct sk_b
+@@ -2039,6 +2040,22 @@ static int nl80211_set_wiphy(struct sk_b
goto bad_res;
}
--- a/include/uapi/linux/nl80211.h
+++ b/include/uapi/linux/nl80211.h
-@@ -1511,6 +1511,9 @@ enum nl80211_commands {
- * @NL80211_ATTR_SUPPORT_5_10_MHZ: A flag indicating that the device supports
- * 5 MHz and 10 MHz channel bandwidth.
+@@ -1514,6 +1514,9 @@ enum nl80211_commands {
+ * @NL80211_ATTR_SUPPORT_10_MHZ: A flag indicating that the device supports
+ * 10 MHz channel bandwidth.
*
+ * @NL80211_ATTR_WIPHY_ANTENNA_GAIN: Configured antenna gain. Used to reduce
+ * transmit power to stay within regulatory limits. u32, dBi.
@@ -46,9 +46,9 @@
* @NL80211_ATTR_MAX: highest attribute number currently defined
* @__NL80211_ATTR_AFTER_LAST: internal use
*/
-@@ -1829,6 +1832,8 @@ enum nl80211_attrs {
-
- NL80211_ATTR_SUPPORT_5_10_MHZ,
+@@ -1833,6 +1836,8 @@ enum nl80211_attrs {
+ NL80211_ATTR_SUPPORT_5_MHZ,
+ NL80211_ATTR_SUPPORT_10_MHZ,
+ NL80211_ATTR_WIPHY_ANTENNA_GAIN,
+
@@ -57,7 +57,7 @@
__NL80211_ATTR_AFTER_LAST,